"""
Yandex translator API
"""
import requests
from requests import exceptions
from deep_translator.constants import BASE_URLS
from deep_translator.exceptions import (RequestError,
                                        ServerException, TranslationNotFound, TooManyRequests)


class YandexTranslator(object):
    """
    class that wraps functions, which use the yandex translator under the hood to translate word(s)
    """

    def __init__(self, api_key=None):
        """
        @param api_key: your yandex api key
        """
        if not api_key:
            raise ServerException(401)
        self.__base_url = BASE_URLS.get("YANDEX")

        self.api_key = api_key
        self.api_version = "v1.5"
        self.api_endpoints = {
            "langs": "getLangs",
            "detect": "detect",
            "translate": "translate",
        }

    def get_supported_languages(self):
        return set(x.split("-")[0] for x in self.dirs)

    @property
    def languages(self):
        return self.get_supported_languages()

    @property
    def dirs(self, proxies=None):

        try:
            url = self.__base_url.format(version=self.api_version, endpoint="getLangs")
            print("url: ", url)
            response = requests.get(url, params={"key": self.api_key}, proxies=proxies)
        except requests.exceptions.ConnectionError:
            raise ServerException(503)
        else:
            data = response.json()

        if response.status_code != 200:
            raise ServerException(response.status_code)
        return data.get("dirs")

    def detect(self, text, proxies=None):
        response = None
        params = {
            "text": text,
            "format": "plain",
            "key": self.api_key,
        }
        try:
            url = self.__base_url.format(version=self.api_version, endpoint="detect")
            response = requests.post(url, data=params, proxies=proxies)

        except RequestError:
            raise
        except ConnectionError:
            raise ServerException(503)
        except ValueError:
            raise ServerException(response.status_code)
        else:
            response = response.json()
        language = response['lang']
        status_code = response['code']
        if status_code != 200:
            raise RequestError()
        elif not language:
            raise ServerException(501)
        return language

    def translate(self, source, target, text, proxies=None):
        params = {
            "text": text,
            "format": "plain",
            "lang": target if source == "auto" else "{}-{}".format(source, target),
            "key": self.api_key
        }
        try:
            url = self.__base_url.format(version=self.api_version, endpoint="translate")
            response = requests.post(url, data=params, proxies=proxies)
        except ConnectionError:
            raise ServerException(503)
        else:
            response = response.json()

        if response['code'] == 429:
            raise TooManyRequests()

        if response['code'] != 200:
            raise ServerException(response['code'])

        if not response['text']:
            raise TranslationNotFound()

        return response['text']

    def translate_file(self, source, target, path):
        """
        translate from a file
        @param source: source language
        @param target: target language
        @param path: path to file
        @return: translated text
        """
        try:
            with open(path) as f:
                text = f.read()

            return self.translate(source, target, text)
        except Exception as e:
            raise e

    def translate_batch(self, source, target, batch):
        """
        translate a batch of texts
        @param source: source language
        @param target: target language
        @param batch: list of texts to translate
        @return: list of translations
        """
        return [self.translate(source, target, text) for text in batch]



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()


# with open('./re') as reqs:
#     requirements = reqs.read()
# print(requirements)
# exit()
setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest>=3', ]

setup(
    author="Nidhal Baccouri",
    author_email='nidhalbacc@gmail.com',
    maintainer="Nidhal Baccouri",
    maintainer_email='nidhalbacc@gmail.com',
    python_requires='>=3.0',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: MIT License',
        'Topic :: Education',
        'Topic :: Software Development',
        'Topic :: Communications',
        'Topic :: Text Processing',
        'Topic :: Text Processing :: Linguistic',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="A flexible python tool to translate between different languages in a simple way.",
    entry_points={
        'console_scripts': [
            'deep_translator=deep_translator.cli:main',
        ],
    },
    install_requires=['requests', 'beautifulsoup4'],
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords=['deep_translator',
              'deepL', 'DeepL',
              'translator',
              'translation',
              'automation',
              'web scraping',
              'google translator', 'google translation', 'google trans',
              'PONS', 'YANDEX', 'MyMemory translator', 'Linguee', 'QCRI',
              'Language', 'Language detection', 'detect language',
              'free translation', 'unlimited translation', 'translate for free'],
    name='deep_translator',
    packages=find_packages(include=['deep_translator']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/nidhaloff/deep_translator',
    version='1.3.7',
    zip_safe=False,
)




import requests
from requests.utils import requote_uri
from deep_translator.constants import BASE_URLS
from deep_translator.exceptions import (RequestError,
                                        ServerException, TranslationNotFound, TooManyRequests)


class DeepL(object):
    """
    class that wraps functions, which use the DeepL translator under the hood to translate word(s)
    """

    def __init__(self, api_key=None):
        """
        @param api_key: your DeepL api key. Get one here: https://www.deepl.com/docs-api/accessing-the-api/
        """

        if not api_key:
            raise ServerException(401)
        self.version = 'v2'
        self.api_key = api_key
        self.__base_url = BASE_URLS.get("DEEPL").format(version=self.version)

    def translate(self, source, target, text):
        params = {
            "auth_key": self.api_key,
            "target_lang": target,
            "source_lang": source,
            "text": text
        }
        try:
            response = requests.get(self.__base_url, params=params)
        except ConnectionError:
            raise ServerException(503)

        else:
            if response.status_code != 200:
                ServerException(response.status_code)
            else:
                res = response.json()
                if not res:
                    raise TranslationNotFound(text)
                return res

    def translate_batch(self, source, target, batch):
        """
        translate a batch of texts
        @param source: source language
        @param target: target language
        @param batch: list of texts to translate
        @return: list of translations
        """
        return [self.translate(source, target, text) for text in batch]


if __name__ == '__main__':
    d = DeepL(api_key="key")
    print(d)
